ObjectsToSyncCount class

Constructors

ObjectsToSyncCount({required int articlesCount, required int boutiqueCount, required int contactsCount, required int ticketsCount})
const

Properties

articlesCount int
final
boutiqueCount int
final
contactsCount int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticketsCount int
final
total int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited