TicketsService class

Inheritance

Constructors

TicketsService(AddTicketRpc addTicketRpc, DisableTicketRpc disableTicketRpc, GetAllTicketsRpc getAllTicketsRpc, RestoreTicketRpc restoreTicketRpc, AddAllTicketsRpc addAllTicketsRpc, DeleteAllTicketsRpc deleteAllTicketsRpc, DeleteTicketRpc deleteTicketRpc)

Properties

addAllTicketsRpc AddAllTicketsAbstractRpc
finalinherited
addTicketRpc AddTicketAbstractRpc
finalinherited
deleteAllTicketsRpc DeleteAllTicketsAbstractRpc
finalinherited
deleteTicketRpc DeleteTicketAbstractRpc
finalinherited
disableTicketRpc DisableTicketAbstractRpc
finalinherited
getAllTicketsRpc GetAllTicketsAbstractRpc
finalinherited
hashCode int
The hash code for this object.
no setterinherited
restoreTicketRpc RestoreTicketAbstractRpc
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

count → const int