ContactsService class
- Inheritance
-
- Object
- ContactsServiceAbstract
- ContactsService
Constructors
- ContactsService(GetContactsAbstractRpc getContactsRpc, CreateAllContactsAbstractRpc createAllContactsRpc, UpdateContactAbstractRpc updateContactRpc, DeleteAllContactsAbstractRpc deleteAllContactsRpc, CreateContactAbstractRpc addContactRpc, DeleteForeverContactAbstractRpc deleteForeverContactRpc, GenerateNextContactIdAbstractRpc generateNextContactIdRpc)
Properties
- createAllContactsRpc → CreateAllContactsAbstractRpc
-
finalinherited
- createContactRpc → CreateContactAbstractRpc
-
finalinherited
- deleteAllContactsRpc → DeleteAllContactsAbstractRpc
-
finalinherited
- deleteForeverContactRpc → DeleteForeverContactAbstractRpc
-
finalinherited
- generateNextContactIdRpc → GenerateNextContactIdAbstractRpc
-
finalinherited
- getContactsRpc → GetContactsAbstractRpc
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateContactRpc → UpdateContactAbstractRpc
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited